import { ReactChildren, ReactChild } from 'react';
import { ConnectDragSource, ConnectDropTarget } from 'react-dnd';
import { Identifier } from 'dnd-core';
export declare enum ChessColor {
    Black = "black",
    Red = "red"
}
export declare enum PieceType {
    General = 0,
    Advisor = 1,
    Elephant = 2,
    Horse = 3,
    Chariot = 4,
    Cannon = 5,
    Soldier = 6
}
export declare type PositionShape = {
    x: number;
    y: number;
};
export declare type PieceShape = {
    id: string;
    name: string;
    type: PieceType;
    color: ChessColor;
    position: PositionShape;
    live: boolean;
};
export interface XiangqiState {
    redPieces: PieceShape[];
    blackPieces: PieceShape[];
    turn: ChessColor;
    channel: object | null;
}
export declare type ContainerState = XiangqiState;
export interface DragDropContextProps {
    redPieces: PieceShape[];
    blackPieces: PieceShape[];
    kill: (item: PieceShape) => PieceShape;
    movePiece: (item: PieceShape, pos: PositionShape) => void;
    turn: ChessColor;
}
export interface ChessBoardProps {
    redPieces: PieceShape[];
    blackPieces: PieceShape[];
    kill: (item: PieceShape) => PieceShape;
    movePiece: (item: PieceShape, pos: PositionShape) => void;
    canDrop: (item: PieceShape, pos: PositionShape, pieces: PieceShape[]) => boolean;
    turn: ChessColor;
}
export interface SquareProps {
    x: number;
    y: number;
    canDrop: (item: PieceShape, pos: PositionShape, pieces: PieceShape[]) => boolean;
    connectDropTarget: ConnectDropTarget;
    piece: PieceShape | null;
    pieces: PieceShape[];
    movePiece: (item: PieceShape, pos: PositionShape) => void;
    kill: () => void;
    isDropable: boolean;
    children: ReactChild | ReactChildren;
}
export interface PieceProps extends DragSourceCollectedProps {
    item: PieceShape;
}
export interface DragSourceProps {
    item: PieceShape;
    turn: ChessColor;
}
export interface DragSourceCollectedProps {
    connectDragSource: ConnectDragSource;
    isDragging: boolean;
}
export interface DropResult {
    moved: boolean;
}
export interface DropTargetCollectedProps {
    connectDropTarget: ConnectDropTarget;
    isOver: boolean;
    isOverCurrent: boolean;
    isDropable: boolean;
    itemType: Identifier | null;
}
